@@ -290,12 +290,12 @@
         <translation>DIREZIONE_LAYOUT_QT</translation>
     </message>
     <message>
-        <source>Executable &apos;%1&apos; requires Qt %2, found Qt %3.</source>
-        <translation>Il file eseguibile &apos;%1&apos; richiede Qt %2, trovato Qt %3.</translation>
+        <source>Executable &apos;%1&apos; requires TQt %2, found TQt %3.</source>
+        <translation>Il file eseguibile &apos;%1&apos; richiede TQt %2, trovato TQt %3.</translation>
     </message>
     <message>
-        <source>Incompatible Qt Library Error</source>
-        <translation>Errore Libreria Qt incompatibile</translation>
+        <source>Incompatible TQt Library Error</source>
+        <translation>Errore Libreria TQt incompatibile</translation>
     </message>
 </context>
 <context>
@@ -1263,8 +1263,8 @@ in
         <translation>&amp;Ignora</translation>
     </message>
     <message>
-        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
-        <translation>&lt;h3&gt;Informazioni su Qt&lt;/h3&gt;&lt;p&gt;Questo programma usa la versione di Qt %1.&lt;/p&gt;&lt;p&gt;Qt è un kit di strumenti C++ per lo sviluppo di applicazioni GUI &amp;amp; multi-piattaforma.&lt;/p&gt;&lt;p&gt;Qt consente di creare un'unica interfaccia portatile compatibile con MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux e le principali varianti commerciali di Unix.&lt;br&gt;Qt è disponibile anche per le periferiche incorporate.&lt;/p&gt;&lt;p&gt;Qt è un prodotto di Trolltech. Per ulteriori informazioni, visitare la pagina Web &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt;.&lt;/p&gt;</translation>
+        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses TQt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
+        <translation>&lt;h3&gt;Informazioni su Qt&lt;/h3&gt;&lt;p&gt;Questo programma usa la versione di TQt %1.&lt;/p&gt;&lt;p&gt;Qt è un kit di strumenti C++ per lo sviluppo di applicazioni GUI &amp;amp; multi-piattaforma.&lt;/p&gt;&lt;p&gt;Qt consente di creare un'unica interfaccia portatile compatibile con MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux e le principali varianti commerciali di Unix.&lt;br&gt;Qt è disponibile anche per le periferiche incorporate.&lt;/p&gt;&lt;p&gt;Qt è un prodotto di Trolltech. Per ulteriori informazioni, visitare la pagina Web &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt;.&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
